summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/extension_browsertests_misc.cc
diff options
context:
space:
mode:
authorjnd@google.com <jnd@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-24 11:31:40 +0000
committerjnd@google.com <jnd@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-24 11:31:40 +0000
commit12ea9b27f4b143c59b6cb749f729025e484e7c5d (patch)
treef63cdf60d6767fa2be6c4c6cf455d3a49ba069c0 /chrome/browser/extensions/extension_browsertests_misc.cc
parentd6aa6b6b5ee96766e099ea83a897faea2ca784af (diff)
downloadchromium_src-12ea9b27f4b143c59b6cb749f729025e484e7c5d.zip
chromium_src-12ea9b27f4b143c59b6cb749f729025e484e7c5d.tar.gz
chromium_src-12ea9b27f4b143c59b6cb749f729025e484e7c5d.tar.bz2
Fix a few test failures when landing http://trac.webkit.org/changeset/57178.
http://trac.webkit.org/changeset/57178 broke some tests in browser_test and ui_test. This patch is same as the patch in http://codereview.chromium.org/3136019/show except test RedirectTest.ClientCancelled. RedirectTest.ClientCancelled was broken on windows platform when landing the original patch. So I revert it. After digging in code, I found the root cause of why the test was broken on windows platform. Please refer to http://crbug.com/53091 for details. So I add FAILS_ prefix to RedirectTest.ClientCancelled on windows platform. BUG=17655 TEST=RedirectTest.ClientCancelled, AppApiTest.AppProcess, ExtensionBrowserTest.WindowOpenExtension, ExtensionBrowserTest.WindowOpenInvalidExtension Review URL: http://codereview.chromium.org/3186023 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@57168 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/extensions/extension_browsertests_misc.cc')
-rw-r--r--chrome/browser/extensions/extension_browsertests_misc.cc7
1 files changed, 5 insertions, 2 deletions
diff --git a/chrome/browser/extensions/extension_browsertests_misc.cc b/chrome/browser/extensions/extension_browsertests_misc.cc
index 4ede48d..9076447 100644
--- a/chrome/browser/extensions/extension_browsertests_misc.cc
+++ b/chrome/browser/extensions/extension_browsertests_misc.cc
@@ -614,8 +614,11 @@ static TabContents* WindowOpenHelper(Browser* browser, const GURL& start_url,
L"window.domAutomationController.send(true);", &result);
EXPECT_TRUE(result);
- // Now the current tab should be the new tab.
- TabContents* newtab = browser->GetSelectedTabContents();
+ // Now the active tab in last active window should be the new tab.
+ Browser* last_active_browser = BrowserList::GetLastActive();
+ EXPECT_TRUE(last_active_browser);
+ TabContents* newtab = last_active_browser->GetSelectedTabContents();
+ EXPECT_TRUE(newtab);
GURL expected_url = start_url.Resolve(newtab_url);
if (!newtab->controller().GetLastCommittedEntry() ||
newtab->controller().GetLastCommittedEntry()->url() != expected_url)